@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io2313.h 1873 2009-02-11 17:53:39Z arcanum $ */
+/* $Id: io2313.h 2456 2014-11-19 09:57:29Z saaadhu $ */
 
 /* avr/io2313.h - definitions for AT90S2313 */
 
@@ -147,42 +147,52 @@
 /* Interrupt vectors */
 
 /* External Interrupt Request 0 */
+#define INT0_vect_num		1
 #define INT0_vect			_VECTOR(1)
 #define SIG_INTERRUPT0			_VECTOR(1)
 
 /* External Interrupt Request 1 */
+#define INT1_vect_num		2
 #define INT1_vect			_VECTOR(2)
 #define SIG_INTERRUPT1			_VECTOR(2)
 
 /* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT1_vect_num	3
 #define TIMER1_CAPT1_vect		_VECTOR(3)
 #define SIG_INPUT_CAPTURE1		_VECTOR(3)
 
 /* Timer/Counter1 Compare Match */
+#define TIMER1_COMP1_vect_num	4
 #define TIMER1_COMP1_vect		_VECTOR(4)
 #define SIG_OUTPUT_COMPARE1A		_VECTOR(4)
 
 /* Timer/Counter1 Overflow */
+#define TIMER1_OVF1_vect_num	5
 #define TIMER1_OVF1_vect		_VECTOR(5)
 #define SIG_OVERFLOW1			_VECTOR(5)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF0_vect_num	6
 #define TIMER0_OVF0_vect		_VECTOR(6)
 #define SIG_OVERFLOW0			_VECTOR(6)
 
 /* UART, Rx Complete */
+#define UART_RX_vect_num		7
 #define UART_RX_vect			_VECTOR(7)
 #define SIG_UART_RECV			_VECTOR(7)
 
 /* UART Data Register Empty */
+#define UART_UDRE_vect_num		8
 #define UART_UDRE_vect			_VECTOR(8)
 #define SIG_UART_DATA			_VECTOR(8)
 
 /* UART, Tx Complete */
+#define UART_TX_vect_num		9
 #define UART_TX_vect			_VECTOR(9)
 #define SIG_UART_TRANS			_VECTOR(9)
 
 /* Analog Comparator */
+#define ANA_COMP_vect_num		10
 #define ANA_COMP_vect			_VECTOR(10)
 #define SIG_COMPARATOR			_VECTOR(10)
 
@@ -342,6 +352,7 @@
 #define    EERE    0
        
 /* Constants */ 
+#define    RAMSTART   0x60
 #define    RAMEND     0xDF
 #define    XRAMEND    RAMEND
 #define    E2END      0x7F
@@ -368,4 +379,8 @@
 #define SIGNATURE_2 0x01
 
 
+#define SLEEP_MODE_IDLE         0
+#define SLEEP_MODE_PWR_DOWN     _BV(SM)
+
+
 #endif  /* _AVR_IO2313_H_ */
