@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom163.h 2231 2011-03-07 05:06:55Z arcanum $ */
+/* $Id: iom163.h 2456 2014-11-19 09:57:29Z saaadhu $ */
 
 /* avr/iom163.h - definitions for ATmega163 */
 
@@ -613,6 +613,7 @@
 
 /* Constants */
 #define SPM_PAGESIZE 128
+#define RAMSTART    0x60
 #define RAMEND		0x45F
 #define XRAMEND		RAMEND
 #define E2END		0x1FF
@@ -681,4 +682,10 @@
 
 
 
+#define SLEEP_MODE_IDLE         0
+#define SLEEP_MODE_ADC          _BV(SM0)
+#define SLEEP_MODE_PWR_DOWN     _BV(SM1)
+#define SLEEP_MODE_PWR_SAVE     (_BV(SM0) | _BV(SM1))
+
+
 #endif /* _AVR_IOM163_H_ */
