@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom16hva.h 2102 2010-03-16 22:52:39Z joerg_wunsch $ */
+/* $Id: iom16hva.h 2456 2014-11-19 09:57:29Z saaadhu $ */
 
 /* iom16hva.h - definitions for ATmega16HVA.  */
 
@@ -39,6 +39,7 @@
 
 /* Constants */
 #define SPM_PAGESIZE 128
+#define RAMSTART    0x100
 #define RAMEND      0x2FF
 #define XRAMEND     RAMEND
 #define E2END       0xFF
@@ -72,4 +73,10 @@
 #define SIGNATURE_2 0x0C
 
 
+#define SLEEP_MODE_IDLE (0x00<<1)
+#define SLEEP_MODE_ADC (0x01<<1)
+#define SLEEP_MODE_PWR_SAVE (0x03<<1)
+#define SLEEP_MODE_PWR_OFF (0x04<<1)
+
+
 #endif /* _AVR_IOM16HVA_H_ */
