@@ -30,7 +30,7 @@
 
 /* avr/iom324.h - definitions for ATmega324 */
 
-/* $Id: iom324.h 2115 2010-04-05 23:19:53Z arcanum $ */
+/* $Id: iom324.h 2483 2015-08-06 09:16:30Z pitchumani $ */
 
 #ifndef _AVR_IOM324_H_
 #define _AVR_IOM324_H_ 1
@@ -91,5 +91,11 @@
 #define SIGNATURE_1 0x95
 #define SIGNATURE_2 0x08 
 
+#define SLEEP_MODE_IDLE (0x00<<1)
+#define SLEEP_MODE_ADC (0x01<<1)
+#define SLEEP_MODE_PWR_DOWN (0x02<<1)
+#define SLEEP_MODE_PWR_SAVE (0x03<<1)
+#define SLEEP_MODE_STANDBY (0x06<<1)
+#define SLEEP_MODE_EXT_STANDBY (0x07<<1)
 
 #endif /* _AVR_IOM324_H_ */
