@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom64c1.h 2183 2010-09-21 05:37:46Z aboyapati $ */
+/* $Id: iom64c1.h 2460 2014-12-03 05:39:25Z pitchumani $ */
 
 /* avr/iom64c1.h - definitions for ATmega64C1 */
 
@@ -398,6 +398,15 @@
 #define PRPSC 5
 #define PRCAN 6
 
+#define __AVR_HAVE_PRR	((1<<PRADC)|(1<<PRLIN)|(1<<PRSPI)|(1<<PRTIM0)|(1<<PRTIM1)|(1<<PRPSC)|(1<<PRCAN))
+#define __AVR_HAVE_PRR_PRADC
+#define __AVR_HAVE_PRR_PRLIN
+#define __AVR_HAVE_PRR_PRSPI
+#define __AVR_HAVE_PRR_PRTIM0
+#define __AVR_HAVE_PRR_PRTIM1
+#define __AVR_HAVE_PRR_PRPSC
+#define __AVR_HAVE_PRR_PRCAN
+
 #define OSCCAL _SFR_MEM8(0x66)
 #define CAL0 0
 #define CAL1 1
@@ -1303,5 +1312,11 @@
 #define SIGNATURE_2 0x86
 
 
+
+#define SLEEP_MODE_IDLE (0x00<<1)
+#define SLEEP_MODE_ADC (0x01<<1)
+#define SLEEP_MODE_PWR_DOWN (0x02<<1)
+#define SLEEP_MODE_STANDBY (0x06<<1)
+
 #endif /* _AVR_ATmega64C1_H_ */
 
