@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom8515.h 2115 2010-04-05 23:19:53Z arcanum $ */
+/* $Id: iom8515.h 2456 2014-11-19 09:57:29Z saaadhu $ */
 
 /* avr/iom8515.h - definitions for ATmega8515 */
 
@@ -209,69 +209,85 @@
 /* Interrupt vectors */
 
 /* External Interrupt Request 0 */
+#define INT0_vect_num		1
 #define INT0_vect			_VECTOR(1)
 #define SIG_INTERRUPT0			_VECTOR(1)
 
 /* External Interrupt Request 1 */
+#define INT1_vect_num		2
 #define INT1_vect			_VECTOR(2)
 #define SIG_INTERRUPT1			_VECTOR(2)
 
 /* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect_num	3
 #define TIMER1_CAPT_vect		_VECTOR(3)
 #define SIG_INPUT_CAPTURE1		_VECTOR(3)
 
 /* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect_num	4
 #define TIMER1_COMPA_vect		_VECTOR(4)
 #define SIG_OUTPUT_COMPARE1A		_VECTOR(4)
 
 /* Timer/Counter1 Compare MatchB */
+#define TIMER1_COMPB_vect_num	5
 #define TIMER1_COMPB_vect		_VECTOR(5)
 #define SIG_OUTPUT_COMPARE1B		_VECTOR(5)
 
 /* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect_num		6
 #define TIMER1_OVF_vect			_VECTOR(6)
 #define SIG_OVERFLOW1			_VECTOR(6)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect_num		7
 #define TIMER0_OVF_vect			_VECTOR(7)
 #define SIG_OVERFLOW0			_VECTOR(7)
 
 /* Serial Transfer Complete */
+#define SPI_STC_vect_num		8
 #define SPI_STC_vect			_VECTOR(8)
 #define SIG_SPI				_VECTOR(8)
 
 /* UART, Rx Complete */
+#define USART_RX_vect_num               9
 #define USART_RX_vect                   _VECTOR(9)
 #define UART_RX_vect                    _VECTOR(9) /* For compatability only */
 #define SIG_UART_RECV                   _VECTOR(9) /* For compatability only */
 
 /* UART Data Register Empty */
+#define USART_UDRE_vect_num             10
 #define USART_UDRE_vect                 _VECTOR(10)
 #define UART_UDRE_vect                  _VECTOR(10) /* For compatability only */
 #define SIG_UART_DATA                   _VECTOR(10) /* For compatability only */
 
 /* UART, Tx Complete */
+#define USART_TX_vect_num               11
 #define USART_TX_vect                   _VECTOR(11)
 #define UART_TX_vect                    _VECTOR(11) /* For compatability only */
 #define SIG_UART_TRANS                  _VECTOR(11) /* For compatability only */
 
 /* Analog Comparator */
+#define ANA_COMP_vect_num		12
 #define ANA_COMP_vect			_VECTOR(12)
 #define SIG_COMPARATOR			_VECTOR(12)
 
 /* External Interrupt Request 2 */
+#define INT2_vect_num		13
 #define INT2_vect			_VECTOR(13)
 #define SIG_INTERRUPT2			_VECTOR(13)
 
 /* Timer 0 Compare Match */
+#define TIMER0_COMP_vect_num	14
 #define TIMER0_COMP_vect		_VECTOR(14)
 #define SIG_OUTPUT_COMPARE0		_VECTOR(14)
 
 /* EEPROM Ready */
+#define EE_RDY_vect_num		15
 #define EE_RDY_vect			_VECTOR(15)
 #define SIG_EEPROM_READY		_VECTOR(15)
 
 /* Store Program Memory Ready */
+#define SPM_RDY_vect_num		16
 #define SPM_RDY_vect			_VECTOR(16)
 #define SIG_SPM_READY			_VECTOR(16)
 
@@ -634,4 +650,40 @@
 #define SIGNATURE_2 0x06
 
 
+/* Deprecated items */
+#if !defined(__AVR_LIBC_DEPRECATED_ENABLE__)
+
+#pragma GCC system_header
+
+#pragma GCC poison SIG_INTERRUPT0
+#pragma GCC poison SIG_INTERRUPT1
+#pragma GCC poison SIG_INPUT_CAPTURE1
+#pragma GCC poison SIG_OUTPUT_COMPARE1A
+#pragma GCC poison SIG_OUTPUT_COMPARE1B
+#pragma GCC poison SIG_OVERFLOW1
+#pragma GCC poison SIG_OVERFLOW0
+#pragma GCC poison SIG_SPI
+#pragma GCC poison UART_RX_vect
+#pragma GCC poison SIG_UART_RECV
+#pragma GCC poison UART_UDRE_vect
+#pragma GCC poison SIG_UART_DATA
+#pragma GCC poison UART_TX_vect
+#pragma GCC poison SIG_UART_TRANS
+#pragma GCC poison SIG_COMPARATOR
+#pragma GCC poison SIG_INTERRUPT2
+#pragma GCC poison SIG_OUTPUT_COMPARE0
+#pragma GCC poison SIG_EEPROM_READY
+#pragma GCC poison SIG_SPM_READY
+
+#endif  /* !defined(__AVR_LIBC_DEPRECATED_ENABLE__) */
+
+
+#define SLEEP_MODE_IDLE         0
+#define SLEEP_MODE_PWR_DOWN     1
+#define SLEEP_MODE_PWR_SAVE     2
+#define SLEEP_MODE_ADC          3
+#define SLEEP_MODE_STANDBY      4
+#define SLEEP_MODE_EXT_STANDBY  5
+
+
 #endif /* _AVR_IOM8515_H_ */
