@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom8535.h,v 1.10 2005/10/30 22:11:23 joerg_wunsch Exp $ */
+/* $Id: iom8535.h 2456 2014-11-19 09:57:29Z saaadhu $ */
 
 /* avr/iom8535.h - definitions for ATmega8535 */
 
@@ -232,82 +232,102 @@
 /* Interrupt vectors */
 
 /* External Interrupt 0 */
+#define INT0_vect_num		1
 #define INT0_vect			_VECTOR(1)
 #define SIG_INTERRUPT0			_VECTOR(1)
 
 /* External Interrupt 1 */
+#define INT1_vect_num		2
 #define INT1_vect			_VECTOR(2)
 #define SIG_INTERRUPT1			_VECTOR(2)
 
 /* Timer/Counter2 Compare Match */
+#define TIMER2_COMP_vect_num	3
 #define TIMER2_COMP_vect		_VECTOR(3)
 #define SIG_OUTPUT_COMPARE2		_VECTOR(3)
 
 /* Timer/Counter2 Overflow */
+#define TIMER2_OVF_vect_num		4
 #define TIMER2_OVF_vect			_VECTOR(4)
 #define SIG_OVERFLOW2			_VECTOR(4)
 
 /* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect_num	5
 #define TIMER1_CAPT_vect		_VECTOR(5)
 #define SIG_INPUT_CAPTURE1		_VECTOR(5)
 
 /* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect_num	6
 #define TIMER1_COMPA_vect		_VECTOR(6)
 #define SIG_OUTPUT_COMPARE1A		_VECTOR(6)
 
 /* Timer/Counter1 Compare Match B */
+#define TIMER1_COMPB_vect_num	7
 #define TIMER1_COMPB_vect		_VECTOR(7)
 #define SIG_OUTPUT_COMPARE1B		_VECTOR(7)
 
 /* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect_num		8
 #define TIMER1_OVF_vect			_VECTOR(8)
 #define SIG_OVERFLOW1			_VECTOR(8)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect_num		9
 #define TIMER0_OVF_vect			_VECTOR(9)
 #define SIG_OVERFLOW0			_VECTOR(9)
 
 /* SPI Serial Transfer Complete */
+#define SPI_STC_vect_num		10
 #define SPI_STC_vect			_VECTOR(10)
 #define SIG_SPI				_VECTOR(10)
 
 /* USART, RX Complete */
+#define USART_RX_vect_num		11
 #define USART_RX_vect			_VECTOR(11)
 #define SIG_UART_RECV			_VECTOR(11)
 
 /* USART Data Register Empty */
+#define USART_UDRE_vect_num		12
 #define USART_UDRE_vect			_VECTOR(12)
 #define SIG_UART_DATA			_VECTOR(12)
 
 /* USART, TX Complete */
+#define USART_TX_vect_num		13
 #define USART_TX_vect			_VECTOR(13)
 #define SIG_UART_TRANS			_VECTOR(13)
 
 /* ADC Conversion Complete */
+#define ADC_vect_num		14
 #define ADC_vect			_VECTOR(14)
 #define SIG_ADC				_VECTOR(14)
 
 /* EEPROM Ready */
+#define EE_RDY_vect_num		15
 #define EE_RDY_vect			_VECTOR(15)
 #define SIG_EEPROM_READY		_VECTOR(15)
 
 /* Analog Comparator */
+#define ANA_COMP_vect_num		16
 #define ANA_COMP_vect			_VECTOR(16)
 #define SIG_COMPARATOR			_VECTOR(16)
 
 /* Two-wire Serial Interface */
+#define TWI_vect_num		17
 #define TWI_vect			_VECTOR(17)
 #define SIG_2WIRE_SERIAL		_VECTOR(17)
 
 /* External Interrupt Request 2 */
+#define INT2_vect_num		18
 #define INT2_vect			_VECTOR(18)
 #define SIG_INTERRUPT2			_VECTOR(18)
 
 /* TimerCounter0 Compare Match */
+#define TIMER0_COMP_vect_num	19
 #define TIMER0_COMP_vect		_VECTOR(19)
 #define SIG_OUTPUT_COMPARE0		_VECTOR(19)
 
 /* Store Program Memory Read */
+#define SPM_RDY_vect_num		20
 #define SPM_RDY_vect			_VECTOR(20)
 #define SIG_SPM_READY			_VECTOR(20)
 
@@ -665,10 +685,90 @@
 #define    EERE         0
 
 /* Constants */
-#define    SPM_PAGESIZE 64
-#define    RAMEND       0x25F    /* Last On-Chip SRAM Location */
-#define    XRAMEND	0x25F
-#define    E2END        0x1FF
-#define    FLASHEND     0x1FFF
+#define SPM_PAGESIZE 64
+#define RAMSTART     (0x60)
+#define RAMEND       0x25F    /* Last On-Chip SRAM Location */
+#define XRAMEND      RAMEND
+#define E2END        0x1FF
+#define E2PAGESIZE   4
+#define FLASHEND     0x1FFF
+
+
+/* Fuses */
+
+#define FUSE_MEMORY_SIZE 2
+
+/* Low Fuse Byte */
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_CKSEL2      (unsigned char)~_BV(2)
+#define FUSE_CKSEL3      (unsigned char)~_BV(3)
+#define FUSE_SUT0        (unsigned char)~_BV(4)
+#define FUSE_SUT1        (unsigned char)~_BV(5)
+#define FUSE_BODEN       (unsigned char)~_BV(6)
+#define FUSE_BODLEVEL    (unsigned char)~_BV(7)
+#define LFUSE_DEFAULT (FUSE_CKSEL1 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_SUT1)
+
+/* High Fuse Byte */
+#define FUSE_BOOTRST     (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0     (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1     (unsigned char)~_BV(2)
+#define FUSE_EESAVE      (unsigned char)~_BV(3)
+#define FUSE_CKOPT       (unsigned char)~_BV(4)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_WDTON       (unsigned char)~_BV(6)
+#define FUSE_S8535C      (unsigned char)~_BV(7)
+#define HFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1 & FUSE_SPIEN)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+#define __BOOT_LOCK_BITS_0_EXIST
+#define __BOOT_LOCK_BITS_1_EXIST 
+
+
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x93
+#define SIGNATURE_2 0x08
+
+
+/* Deprecated items */
+#if !defined(__AVR_LIBC_DEPRECATED_ENABLE__)
+
+#pragma GCC system_header
+
+#pragma GCC poison SIG_INTERRUPT0
+#pragma GCC poison SIG_INTERRUPT1
+#pragma GCC poison SIG_OUTPUT_COMPARE2
+#pragma GCC poison SIG_OVERFLOW2
+#pragma GCC poison SIG_INPUT_CAPTURE1
+#pragma GCC poison SIG_OUTPUT_COMPARE1A
+#pragma GCC poison SIG_OUTPUT_COMPARE1B
+#pragma GCC poison SIG_OVERFLOW1
+#pragma GCC poison SIG_OVERFLOW0
+#pragma GCC poison SIG_SPI
+#pragma GCC poison SIG_UART_RECV
+#pragma GCC poison SIG_UART_DATA
+#pragma GCC poison SIG_UART_TRANS
+#pragma GCC poison SIG_ADC
+#pragma GCC poison SIG_EEPROM_READY
+#pragma GCC poison SIG_COMPARATOR
+#pragma GCC poison SIG_2WIRE_SERIAL
+#pragma GCC poison SIG_INTERRUPT2
+#pragma GCC poison SIG_OUTPUT_COMPARE0
+#pragma GCC poison SIG_SPM_READY
+
+#endif  /* !defined(__AVR_LIBC_DEPRECATED_ENABLE__) */
+
+
+
+#define SLEEP_MODE_IDLE (0x00<<4)
+#define SLEEP_MODE_ADC (0x01<<4)
+#define SLEEP_MODE_PWR_DOWN (0x02<<4)
+#define SLEEP_MODE_PWR_SAVE (0x03<<4)
+#define SLEEP_MODE_STANDBY (0x0A<<4)
+#define SLEEP_MODE_EXT_STANDBY (0x0B<<4)
+
 
 #endif /* _AVR_IOM8535_H_ */
