@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: iotn43u.h 2225 2011-03-02 16:27:26Z arcanum $ */
+/* $Id: iotn43u.h 2460 2014-12-03 05:39:25Z pitchumani $ */
 
 /* avr/iotn43u.h - definitions for ATtiny43U */
 
@@ -57,6 +57,12 @@
 #define PRTIM0 2
 #define PRTIM1 3
 
+#define __AVR_HAVE_PRR	((1<<PRADC)|(1<<PRUSI)|(1<<PRTIM0)|(1<<PRTIM1))
+#define __AVR_HAVE_PRR_PRADC
+#define __AVR_HAVE_PRR_PRUSI
+#define __AVR_HAVE_PRR_PRTIM0
+#define __AVR_HAVE_PRR_PRTIM1
+
 #define DIDR0 _SFR_IO8(0x01)
 #define ADC0D  0
 #define ADC1D  1
@@ -74,7 +80,7 @@
 #define ADLAR  4
 #define ACME   6
 
-#ifndef _ASSEMBLER_
+#ifndef __ASSEMBLER__
 #define ADC _SFR_IO16(0x04)
 #endif
 #define ADCW _SFR_IO16(0x04)
@@ -543,6 +549,7 @@
 
 /* Constants */
 #define SPM_PAGESIZE   64
+#define RAMSTART       0x60
 #define RAMEND         0x15F
 #define XRAMEND        RAMEND
 #define E2END          0x3F
@@ -590,4 +597,10 @@
 #define SIGNATURE_2 0x0C
 
 
+#define SLEEP_MODE_IDLE (0x00<<3)
+#define SLEEP_MODE_ADC (0x01<<3)
+#define SLEEP_MODE_PWR_DOWN (0x02<<3)
+#define SLEEP_MODE_STANDBY (0x03<<3)
+
+
 #endif /* _AVR_IOTN43U_H_ */
