@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iousb1286.h,v 1.2.2.2 2008/01/06 20:10:48 arcanum Exp $ */
+/* $Id: iousb1286.h 2456 2014-11-19 09:57:29Z saaadhu $ */
 
 /* avr/iousb1286.h - definitions for AT90USB1286 */
 
@@ -38,44 +38,45 @@
 #include <avr/iousbxx6_7.h>
 
 /* Constants */
-#define SPM_PAGESIZE    256
-#define RAMEND          0x20FF
-#define XRAMEND         0xFFFF
-#define E2END           0xFFF
-#define FLASHEND        0x1FFFF
+#define SPM_PAGESIZE 256
+#define RAMSTART     0x100
+#define RAMEND       0x20FF
+#define XRAMEND      0xFFFF
+#define E2END        0xFFF
+#define E2PAGESIZE   8
+#define FLASHEND     0x1FFFF
 
 
 /* Fuses */
-
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define FUSE_CKSEL0      ~_BV(0)
-#define FUSE_CKSEL1      ~_BV(1)
-#define FUSE_CKSEL2      ~_BV(2)
-#define FUSE_CKSEL3      ~_BV(3)
-#define FUSE_SUT0        ~_BV(4)
-#define FUSE_SUT1        ~_BV(5)
-#define FUSE_CKOUT       ~_BV(6)
-#define FUSE_CKDIV8      ~_BV(7)
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_CKSEL2      (unsigned char)~_BV(2)
+#define FUSE_CKSEL3      (unsigned char)~_BV(3)
+#define FUSE_SUT0        (unsigned char)~_BV(4)
+#define FUSE_SUT1        (unsigned char)~_BV(5)
+#define FUSE_CKOUT       (unsigned char)~_BV(6)
+#define FUSE_CKDIV8      (unsigned char)~_BV(7)
 #define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define FUSE_BOOTRST     ~_BV(0)
-#define FUSE_BOOTSZ0     ~_BV(1)
-#define FUSE_BOOTSZ1     ~_BV(2)
-#define FUSE_EESAVE      ~_BV(3)
-#define FUSE_WDTON       ~_BV(4)
-#define FUSE_SPIEN       ~_BV(5)
-#define FUSE_JTAGEN      ~_BV(6)
-#define FUSE_OCDEN       ~_BV(7)
+#define FUSE_BOOTRST     (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0     (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1     (unsigned char)~_BV(2)
+#define FUSE_EESAVE      (unsigned char)~_BV(3)
+#define FUSE_WDTON       (unsigned char)~_BV(4)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_JTAGEN      (unsigned char)~_BV(6)
+#define FUSE_OCDEN       (unsigned char)~_BV(7)
 #define HFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1 & FUSE_SPIEN & FUSE_JTAGEN)
 
 /* Extended Fuse Byte */
-#define FUSE_BODLEVEL0   ~_BV(0)
-#define FUSE_BODLEVEL1   ~_BV(1)
-#define FUSE_BODLEVEL2   ~_BV(2)
-#define FUSE_HWBE        ~_BV(3)
+#define FUSE_BODLEVEL0   (unsigned char)~_BV(0)
+#define FUSE_BODLEVEL1   (unsigned char)~_BV(1)
+#define FUSE_BODLEVEL2   (unsigned char)~_BV(2)
+#define FUSE_HWBE        (unsigned char)~_BV(3)
 #define EFUSE_DEFAULT (FUSE_BODLEVEL2 & FUSE_HWBE)
 
 
@@ -85,4 +86,18 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x97
+#define SIGNATURE_2 0x82
+
+
+#define SLEEP_MODE_IDLE (0x00<<1)
+#define SLEEP_MODE_ADC (0x01<<1)
+#define SLEEP_MODE_PWR_DOWN (0x02<<1)
+#define SLEEP_MODE_PWR_SAVE (0x03<<1)
+#define SLEEP_MODE_STANDBY (0x06<<1)
+#define SLEEP_MODE_EXT_STANDBY (0x07<<1)
+
+
 #endif /* _AVR_AT90USB1286_H_ */
