@@ -32,7 +32,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: math.h 2064 2009-11-29 06:19:16Z dmix $ */
+/* $Id: math.h 2503 2016-02-07 22:59:47Z joerg_wunsch $ */
 
 /*
    math.h - mathematical functions
@@ -56,7 +56,7 @@
     functions.
 
     \par Notes:
-    - In order to access the functions delcared herein, it is usually
+    - In order to access the functions declared herein, it is usually
       also required to additionally link against the library \c libm.a.
       See also the related \ref faq_libm "FAQ entry".
     - Math functions do not raise exceptions and do not change the
@@ -167,15 +167,16 @@ extern double fmod(double __x, double __y) __ATTR_CONST__;
  */
 extern double modf(double __x, double *__iptr);
 
-/** The alias for modf().
- */
+/** An alias for modf(). */
 extern float modff (float __x, float *__iptr);
 
 /**
     The sqrt() function returns the non-negative square root of \a __x.
  */
 extern double sqrt(double __x) __ATTR_CONST__;
-#define sqrtf	sqrt		/**< The alias for sqrt().	*/
+
+/** An alias for sqrt(). */
+extern float sqrtf (float) __ATTR_CONST__;
 
 /**
     The cbrt() function returns the cube root of \a __x.
