@@ -1,6 +1,7 @@
 /* Copyright (c) 2002,2004,2005 Marek Michalkiewicz
    Copyright (c) 2005, Carlos Lamas
    Copyright (c) 2005,2007 Joerg Wunsch
+   Copyright (c) 2013 Embecosm
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -30,7 +31,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: stdint.h 1196 2007-01-23 15:34:58Z joerg_wunsch $ */
+/* $Id: stdint.h 2503 2016-02-07 22:59:47Z joerg_wunsch $ */
 
 /*
  * ISO/IEC 9899:1999  7.18 Integer types <stdint.h>
@@ -48,6 +49,7 @@
     Since these typedefs are mandated by the C99 standard, they are preferred
     over rolling your own typedefs.  */
 
+#ifndef __DOXYGEN__
 /*
  * __USING_MINT8 is defined to 1 if the -mint8 option is in effect.
  */
@@ -57,6 +59,8 @@
 # define __USING_MINT8 0
 #endif
 
+#endif	/* !__DOXYGEN__ */
+
 /* Integer types */
 
 #if defined(__DOXYGEN__)
@@ -118,14 +122,14 @@ typedef unsigned long long int uint64_t;
 
 /* actual implementation goes here */
 
-typedef int int8_t __attribute__((__mode__(__QI__)));
+typedef signed int int8_t __attribute__((__mode__(__QI__)));
 typedef unsigned int uint8_t __attribute__((__mode__(__QI__)));
-typedef int int16_t __attribute__ ((__mode__ (__HI__)));
+typedef signed int int16_t __attribute__ ((__mode__ (__HI__)));
 typedef unsigned int uint16_t __attribute__ ((__mode__ (__HI__)));
-typedef int int32_t __attribute__ ((__mode__ (__SI__)));
+typedef signed int int32_t __attribute__ ((__mode__ (__SI__)));
 typedef unsigned int uint32_t __attribute__ ((__mode__ (__SI__)));
 #if !__USING_MINT8
-typedef int int64_t __attribute__((__mode__(__DI__)));
+typedef signed int int64_t __attribute__((__mode__(__DI__)));
 typedef unsigned int uint64_t __attribute__((__mode__(__DI__)));
 #endif
 
@@ -280,12 +284,15 @@ typedef uint64_t uintmax_t;
 
 /*@}*/
 
+#ifndef __DOXYGEN__
 /* Helping macro */
 #ifndef __CONCAT
 #define __CONCATenate(left, right) left ## right
 #define __CONCAT(left, right) __CONCATenate(left, right)
 #endif
 
+#endif	/* !__DOXYGEN__ */
+
 #if !defined(__cplusplus) || defined(__STDC_LIMIT_MACROS)
 
 /** \name Limits of specified-width integer types
@@ -304,13 +311,10 @@ typedef uint64_t uintmax_t;
 
 #define INT8_MIN (-INT8_MAX - 1)
 
-/** \ingroup avr_stdint
-    largest value an uint8_t can hold. */
+#if __USING_MINT8
 
 #define UINT8_MAX (__CONCAT(INT8_MAX, U) * 2U + 1U)
 
-#if __USING_MINT8
-
 #define INT16_MAX 0x7fffL
 #define INT16_MIN (-INT16_MAX - 1L)
 #define UINT16_MAX (__CONCAT(INT16_MAX, U) * 2UL + 1UL)
@@ -321,6 +325,11 @@ typedef uint64_t uintmax_t;
 
 #else /* !__USING_MINT8 */
 
+/** \ingroup avr_stdint
+    largest value an uint8_t can hold. */
+
+#define UINT8_MAX (INT8_MAX * 2 + 1)
+
 /** \ingroup avr_stdint
     largest positive value an int16_t can hold. */
 
@@ -577,7 +586,7 @@ typedef uint64_t uintmax_t;
 /** \ingroup avr_stdint
     largest value a size_t can hold. */
 
-#define SIZE_MAX (__CONCAT(INT16_MAX, U))
+#define SIZE_MAX UINT16_MAX
 
 
 /* Limits of wchar_t */
@@ -588,13 +597,20 @@ typedef uint64_t uintmax_t;
 
 /* Limits of wint_t */
 /* wchar.h is currently not implemented */
-/* #define WINT_MAX */
-/* #define WINT_MIN */
+#ifndef WCHAR_MAX
+#define WCHAR_MAX __WCHAR_MAX__
+#define WCHAR_MIN __WCHAR_MIN__
+#endif
+#ifndef WINT_MAX
+#define WINT_MAX __WINT_MAX__
+#define WINT_MIN __WINT_MIN__
+#endif
 
 
 #endif /* !defined(__cplusplus) || defined(__STDC_LIMIT_MACROS) */
 
-#if !defined(__cplusplus) || defined(__STDC_CONSTANT_MACROS)
+#if (!defined __cplusplus || __cplusplus >= 201103L \
+     || defined __STDC_CONSTANT_MACROS)
 
 /** \name Macros for integer constants
     C++ implementations should define these macros only when
@@ -603,6 +619,20 @@ typedef uint64_t uintmax_t;
     These definitions are valid for integer constants without suffix and
     for macros defined as integer constant without suffix */
 
+/* The GNU C preprocessor defines special macros in the implementation
+   namespace to allow a definition that works in #if expressions.  */
+#ifdef __INT8_C
+#define INT8_C(c) __INT8_C(c)
+#define INT16_C(c) __INT16_C(c)
+#define INT32_C(c) __INT32_C(c)
+#define INT64_C(c) __INT64_C(c)
+#define UINT8_C(c) __UINT8_C(c)
+#define UINT16_C(c) __UINT16_C(c)
+#define UINT32_C(c) __UINT32_C(c)
+#define UINT64_C(c) __UINT64_C(c)
+#define INTMAX_C(c) __INTMAX_C(c)
+#define UINTMAX_C(c) __UINTMAX_C(c)
+#else
 /** \ingroup avr_stdint
     define a constant of type int8_t */
 
@@ -665,9 +695,12 @@ typedef uint64_t uintmax_t;
 
 #define UINTMAX_C(value) __CONCAT(value, ULL)
 
+#endif /* !__INT8_C */
+
 /*@}*/
 
-#endif /* !defined(__cplusplus) || defined(__STDC_LIMIT_MACROS) */
+#endif /* (!defined __cplusplus || __cplusplus >= 201103L \
+	   || defined __STDC_CONSTANT_MACROS) */
 
 
 #endif /* _STDINT_H_ */
