@@ -1,5 +1,7 @@
 /* Copyright (c) 2002, 2003, 2004  Marek Michalkiewicz
-   Copyright (c) 2005, Joerg Wunsch
+   Copyright (c) 2005, 2007 Joerg Wunsch
+   Copyright (c) 2013 Dave Hylands
+   Copyright (c) 2013 Frederic Nadeau
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -29,13 +31,14 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: crc16.h,v 1.2.2.1 2006/04/19 20:35:54 joerg_wunsch Exp $ */
+/* $Id: crc16.h 2398 2013-05-08 11:45:54Z joerg_wunsch $ */
 
 #ifndef _UTIL_CRC16_H_
 #define _UTIL_CRC16_H_
 
 #include <stdint.h>
 
+/** \file */
 /** \defgroup util_crc <util/crc16.h>: CRC Computations
     \code#include <util/crc16.h>\endcode
 
@@ -321,9 +324,8 @@ _crc_ibutton_update(uint8_t __crc, uint8_t __data)
 		"	eor	%0, %4" "\n\t"
 		"	ldi	%1, 8" "\n\t"
 		"	ldi	%2, 0x8C" "\n\t"
-		"1:	bst	%0, 0" "\n\t"
-		"	lsr	%0" "\n\t"
-		"	brtc	2f" "\n\t"
+		"1:	lsr	%0" "\n\t"
+		"	brcc	2f" "\n\t"
 		"	eor	%0, %2" "\n\t"
 		"2:	dec	%1" "\n\t"
 		"	brne	1b" "\n\t"
@@ -332,4 +334,70 @@ _crc_ibutton_update(uint8_t __crc, uint8_t __data)
 	return __crc;
 }
 
+/** \ingroup util_crc
+    Optimized CRC-8-CCITT calculation.
+
+    Polynomial: x^8 + x^2 + x + 1 (0xE0)<br>
+    
+    For use with simple CRC-8<br>
+    Initial value: 0x0
+    
+    For use with CRC-8-ROHC<br>
+    Initial value: 0xff<br>
+    Reference: http://tools.ietf.org/html/rfc3095#section-5.9.1
+    
+    For use with CRC-8-ATM/ITU<br>
+    Initial value: 0xff<br>
+    Final XOR value: 0x55<br>
+    Reference: http://www.itu.int/rec/T-REC-I.432.1-199902-I/en
+    
+    The C equivalent has been originally written by Dave Hylands.
+    Assembly code is based on _crc_ibutton_update optimization.
+
+    The following is the equivalent functionality written in C.
+
+    \code
+    uint8_t
+    _crc8_ccitt_update (uint8_t inCrc, uint8_t inData)
+    {
+        uint8_t   i;
+        uint8_t   data;
+
+        data = inCrc ^ inData;
+
+        for ( i = 0; i < 8; i++ )
+        {
+            if (( data & 0x80 ) != 0 )
+            {
+                data <<= 1;
+                data ^= 0x07;
+            }
+            else
+            {
+                data <<= 1;
+            }
+        }
+        return data;
+    }
+    \endcode
+*/
+
+static __inline__ uint8_t
+_crc8_ccitt_update(uint8_t __crc, uint8_t __data)
+{
+    uint8_t __i, __pattern;
+    __asm__ __volatile__ (
+        "    eor    %0, %4" "\n\t"
+        "    ldi    %1, 8" "\n\t"
+        "    ldi    %2, 0x07" "\n\t"
+        "1:  lsl    %0" "\n\t"
+        "    brcc   2f" "\n\t"
+        "    eor    %0, %2" "\n\t"
+        "2:  dec    %1" "\n\t"
+        "    brne   1b" "\n\t"
+        : "=r" (__crc), "=d" (__i), "=d" (__pattern)
+        : "0" (__crc), "r" (__data));
+    return __crc;
+}
+
 #endif /* _UTIL_CRC16_H_ */
